==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/ColorScaleDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PropertyUpdatedEventArgsDescriptionMetadata } from "./PropertyUpdatedEventArgsDescriptionMetadata";
/**
 * @hidden
 */
export let ColorScaleDescriptionMetadata = /*@__PURE__*/ (() => {
    class ColorScaleDescriptionMetadata extends Base {
        static b(a) {
            if (ColorScaleDescriptionMetadata.a == null) {
                ColorScaleDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ColorScaleDescriptionMetadata.c(ColorScaleDescriptionMetadata.a);
            }
            if (a.j(ColorScaleDescriptionMetadata.a)) {
                return;
            }
            a.y(ColorScaleDescriptionMetadata.a);
            PropertyUpdatedEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("PropertyUpdatedRef", "EventRef::propertyUpdated");
        }
        static d(a) {
            ColorScaleDescriptionMetadata.b(a);
            a.z("ColorScale", ColorScaleDescriptionMetadata.a);
        }
    }
    ColorScaleDescriptionMetadata.$t = /*@__PURE__*/ markType(ColorScaleDescriptionMetadata, 'ColorScaleDescriptionMetadata');
    ColorScaleDescriptionMetadata.a = null;
    return ColorScaleDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/ColorScaleDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { PropertyUpdatedEventArgsDescriptionMetadata } from "./PropertyUpdatedEventArgsDescriptionMetadata";
/**
 * @hidden
 */
export let ColorScaleDescriptionMetadata = /*@__PURE__*/ (() => {
    class ColorScaleDescriptionMetadata extends Base {
        static b(a) {
            if (ColorScaleDescriptionMetadata.a == null) {
                ColorScaleDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ColorScaleDescriptionMetadata.c(ColorScaleDescriptionMetadata.a);
            }
            if (a.k(ColorScaleDescriptionMetadata.a)) {
                return;
            }
            a.aa(ColorScaleDescriptionMetadata.a);
            PropertyUpdatedEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("PropertyUpdatedRef", "EventRef::propertyUpdated");
        }
        static d(a) {
            ColorScaleDescriptionMetadata.b(a);
            a.ab("ColorScale", ColorScaleDescriptionMetadata.a);
        }
    }
    ColorScaleDescriptionMetadata.$t = /*@__PURE__*/ markType(ColorScaleDescriptionMetadata, 'ColorScaleDescriptionMetadata');
    ColorScaleDescriptionMetadata.a = null;
    return ColorScaleDescriptionMetadata;
})();
